#!/usr/bin/python -B
# vim: autoindent tabstop=8 shiftwidth=4 expandtab softtabstop=4 filetype=python

#
# slate -- create a slate using imagemagick
#
#     xx/xx/2003 v1.0 erco@3dsite.com - perl implementation
#     12/20/2021 v1.1 erco@seriss.com - python port
#

import os,sys,time

# USER MODIFIABLE DEFAULTS
image   = "/var/tmp/slate.0000.png"
xres    = 720
yres    = 486
bgcolor = "#000000"              # slate background color in hex (RRGGBB)
fgcolor = "#ffffff"              # slate text color in hex (RRGGBB)
company = "Degraf/Wahrman Inc."  # your company name
show    = "?"
shot    = "?"
take    = "?"
td      = str(os.getlogin())
date    = str(time.ctime())
notes   = ""

'Show help and exit program function'
def HelpAndExit():
    sys.stderr.write('''
Usage: 
    slate [options]

Options:
    -show <showname>    - The name of the show, "'''+show+'''" default
    -shot <shotname>    - The name of the shot, "'''+shot+'''" default
    -take <takenum>     - The take number, "'''+take+'''" default
    -td <username>      - The td's name, default is current user's login name
    -date <datestr>     - The date string, default is current date/time ('''+date+''')
    -notes <text>       - The notes. Default is no text. Several notes
                          strings can be specified, for individual lines.
    -xres <width>       - The slate image width in pixels. Default '''+str(xres)+'''
    -yres <height>      - The slate image height in pixels. Default '''+str(yres)+'''
    -image <pathname>   - The output image pathname. Default is '''+image+'''

Examples:
    slate -show HONDA -shot 4A -notes "Door touch ups" -notes "FINAL/approved"
''')
    sys.exit(0)

# MAIN
if __name__ == "__main__":
    # PARSE COMMAND LINE ARGUMENTS
    t = 1
    while ( t < len(sys.argv) ):
        if ( sys.argv[t] == "-help" ):
            HelpAndExit()
        elif ( sys.argv[t] == "-show" ):
            t += 1
            show = sys.argv[t]
        elif ( sys.argv[t] == "-shot" ):
            t += 1
            shot = sys.argv[t]
        elif ( sys.argv[t] == "-take" ):
            t += 1
            take = sys.argv[t]
        elif ( sys.argv[t] == "-td"   ):
            t += 1
            td = sys.argv[t]
        elif ( sys.argv[t] == "-date" ):
            t += 1
            date = sys.argv[t]
        elif ( sys.argv[t] == "-xres" ):
            t += 1
            xres = sys.argv[t]
        elif ( sys.argv[t] == "-yres" ):
            t += 1
            yres = sys.argv[t]
        elif ( sys.argv[t] == "-image"):
            t += 1
            image = sys.argv[t]
        elif ( sys.argv[t] == "-notes"):
            t += 1
            notes += sys.argv[t] + "\n"
        else:
            sys.stderr.write(sys.argv[0]
                            + ": unknown argument '"
                            + sys.argv[t] + "'\n")
            sys.exit(1)
        t += 1

    notes = notes.replace("\n", "\n    ")

    # First, create an image of specified size and bgcolor
    # cmd = "convert -size " + xres + "x" + yres + " 'XC:" + bgcolor + "' " + image
    cmd = "convert -size %dx%d 'XC:%s' %s" % (xres,yres,bgcolor,image)
    sys.stdout.write("\n--- EXECUTING: " + cmd + "\n")
    sys.stdout.flush()
    os.system(cmd)

    # DRAW SLATE GRAPHICS
    #    White rhombuses scaled to image size.

    # COORDS
    xscale = ( xres / 1000.0 )
    yscale = ( yres / 1000.0 )
    cmd    = "mogrify -fill '" + fgcolor + "' "
    for t in range(0, 1000, 200):
        x1 = t
        x2 = t + 100
        x3 = t + 200
        x4 = t + 100
        y1 = 100
        cmd += ("-draw 'scale %.2f,%.2f polygon %d,%d %d,%d %d,%d %d,%d' " %
                (xscale,yscale,x1,0,x2,0,x3,y1,x4,y1)
               )
    cmd += image
    sys.stdout.write("\n--- EXECUTING: " + cmd + "\n")
    sys.stdout.flush()
    os.system(cmd)

    # Draw company name large
    xscale = 4 * (xres / 720.0)
    yscale = 3 * (yres / 486.0)
    x      = ((1.0 / 10.0) * xres) / xscale
    y      = ((1.0 /  4.0) * yres) / yscale
    cmd  = "mogrify -fill '%s' " % fgcolor
    cmd += "-draw 'scale %.2f,%.2f " % (xscale,yscale)
    cmd += "text %d,%d \"%s\"'" % (x,y,company)
    cmd += " " + image
    sys.stdout.write("\n--- EXECUTING: " + cmd + "\n")
    sys.stdout.flush()
    os.system(cmd)

    # Draw show/shot/take/animator/date
    cmd    = "mogrify -fill '" + fgcolor + "' "
    xscale = 2 * (xres / 720.0)
    yscale = 2 * (yres / 486.0)
    x      = ((1.0 / 10.0) * xres) / xscale
    y      = ((2.0 /  5.0) * yres) / yscale
    cmd    += "-draw 'scale %.2f,%.2f " % (xscale,yscale)
    cmd    +=        "text %d,%d \"Show: %s\n" % (x,y,show)
    cmd    +=                     "Shot: %s\n" % shot
    cmd    +=                     "Take: %s\n" % take
    cmd    +=                     "TD: %s\n"   % td
    cmd    +=                     "Date: %s\n" % date
    cmd    +=                     "Notes:\n    %s\"" % notes
    cmd += "' " + image
    sys.stdout.write("\n--- EXECUTING: " + cmd + "\n")
    sys.stdout.flush()
    os.system(cmd)

sys.exit(0)
